Description: Lists all of the available service-specific resources, actions, and condition keys that can be used in IAM policies to control access to Amazon Macie.

Actions, resources, and condition keys for Amazon Macie - Service Authorization Reference

# Actions, resources, and condition keys for Amazon Macie

Amazon Macie (service prefix: `macie2` ) provides the following service-specific resources, actions, and condition context keys for use in IAM permission policies.

References:

- Learn how to configure this service .

- View a list of the API operations available for this service .

- Learn how to secure this service and its resources by using IAM permission policies.

###### Topics

- Actions defined by Amazon Macie
- Resource types defined by Amazon Macie
- Condition keys for Amazon Macie

## Actions defined by Amazon Macie

You can specify the following actions in the `Action` element of an IAM policy statement. Use policies to grant permissions to perform an operation in AWS. When you use an action in a policy, you usually allow or deny access to the API operation or CLI command with the same name. However, in some cases, a single action controls access to more than one operation. Alternatively, some operations require several different actions.

The Resource types column of the Actions table indicates whether each action supports resource-level permissions. If there is no value for this column, you must specify all resources ("*") to which the policy applies in the `Resource` element of your policy statement. If the column includes a resource type, then you can specify an ARN of that type in a statement with that action. If the action has one or more required resources, the caller must have permission to use the action with those resources. Required resources are indicated in the table with an asterisk (*). If you limit resource access with the `Resource` element in an IAM policy, you must include an ARN or pattern for each required resource type. Some actions support multiple resource types. If the resource type is optional (not indicated as required), then you can choose to use one of the optional resource types.

The Condition keys column of the Actions table includes keys that you can specify in a policy statement's `Condition` element. For more information on the condition keys that are associated with resources for the service, see the Condition keys column of the Resource types table.

###### Note

Resource condition keys are listed in the Resource types table. You can find a link to the resource type that applies to an action in the Resource types (*required) column of the Actions table. The resource type in the Resource types table includes the Condition keys column, which are the resource condition keys that apply to an action in the Actions table.

For details about the columns in the following table, see Actions table .

###### Note

The DisassociateFromMasterAccount and GetMasterAccount actions have been deprecated. We recommend that you specify the DisassociateFromAdministratorAccount and GetAdministratorAccount actions respectively instead.

Actions | Description | Access level | Resource types (*required) | Condition keys | Dependent actions
--- | --- | --- | --- | --- | ---
AcceptInvitation | Grants permission to accept an Amazon Macie membership invitation | Write |  |  |
BatchGetCustomDataIdentifiers | Grants permission to retrieve information about one or more custom data identifiers | Read | CustomDataIdentifier* |  |
CreateAllowList | Grants permission to create and define the settings for an allow list | Write |  | aws:RequestTag/${TagKey} aws:TagKeys |
CreateClassificationJob | Grants permission to create and define the settings for a sensitive data discovery job | Write | ClassificationJob* |  |
| aws:RequestTag/${TagKey} aws:TagKeys |
CreateCustomDataIdentifier | Grants permission to create and define the settings for a custom data identifier | Write | CustomDataIdentifier* |  |
| aws:RequestTag/${TagKey} aws:TagKeys |
CreateFindingsFilter | Grants permission to create and define the settings for a findings filter | Write | FindingsFilter* |  |
| aws:RequestTag/${TagKey} aws:TagKeys |
CreateInvitations | Grants permission to send an Amazon Macie membership invitation | Write |  |  |
CreateMember | Grants permission to associate an account with an Amazon Macie administrator account | Write | Member* |  |
| aws:RequestTag/${TagKey} aws:TagKeys |
CreateSampleFindings | Grants permission to create sample findings | Write |  |  |
DeclineInvitations | Grants permission to decline Amazon Macie membership invitations | Write |  |  |
DeleteAllowList | Grants permission to delete an allow list | Write | AllowList* |  |
DeleteCustomDataIdentifier | Grants permission to delete a custom data identifier | Write | CustomDataIdentifier* |  |
DeleteFindingsFilter | Grants permission to delete a findings filter | Write | FindingsFilter* |  |
DeleteInvitations | Grants permission to delete Amazon Macie membership invitations | Write |  |  |
DeleteMember | Grants permission to delete the association between an Amazon Macie administrator account and an account | Write | Member* |  |
DescribeBuckets | Grants permission to retrieve statistical data and other information about S3 buckets that Amazon Macie monitors and analyzes | Read |  |  |
DescribeClassificationJob | Grants permission to retrieve information about the status and settings for a sensitive data discovery job | Read | ClassificationJob* |  |
DescribeOrganizationConfiguration | Grants permission to retrieve information about the Amazon Macie configuration settings for an AWS organization | Read |  |  |
DisableMacie | Grants permission to disable an Amazon Macie account, which also deletes Macie resources for the account | Write |  |  |
DisableOrganizationAdminAccount | Grants permission to disable an account as the delegated Amazon Macie administrator account for an AWS organization | Write |  |  |
DisassociateFromAdministratorAccount | Grants permission to an Amazon Macie member account to disassociate from its Macie administrator account | Write |  |  |
DisassociateFromMasterAccount | Grants permission to an Amazon Macie member account to disassociate from its Macie administrator account | Write |  |  |
DisassociateMember | Grants permission to an Amazon Macie administrator account to disassociate from a Macie member account | Write | Member* |  |
EnableMacie | Grants permission to enable and specify the configuration settings for a new Amazon Macie account | Write |  |  |
EnableOrganizationAdminAccount | Grants permission to enable an account as the delegated Amazon Macie administrator account for an AWS organization | Write |  |  |
GetAdministratorAccount | Grants permission to retrieve information about the Amazon Macie administrator account for an account | Read |  |  |
GetAllowList | Grants permission to retrieve the settings and status of an allow list | Read | AllowList* |  |
GetAutomatedDiscoveryConfiguration | Grants permission to retrieve the configuration settings and status of automated sensitive data discovery for an account | Read |  |  |
GetBucketStatistics | Grants permission to retrieve aggregated statistical data for all the S3 buckets that Amazon Macie monitors and analyzes | Read |  |  |
GetClassificationExportConfiguration | Grants permission to retrieve the settings for exporting sensitive data discovery results | Read |  |  |
GetClassificationScope | Grants permission to retrieve the classification scope settings for an account | Read |  |  |
GetCustomDataIdentifier | Grants permission to retrieve information about the settings for a custom data identifier | Read | CustomDataIdentifier* |  |
GetFindingStatistics | Grants permission to retrieve aggregated statistical data about findings | Read |  |  |
GetFindings | Grants permission to retrieve the details of one or more findings | Read |  |  |
GetFindingsFilter | Grants permission to retrieve information about the settings for a findings filter | Read | FindingsFilter* |  |
GetFindingsPublicationConfiguration | Grants permission to retrieve the configuration settings for publishing findings to AWS Security Hub | Read |  |  |
GetInvitationsCount | Grants permission to retrieve the count of Amazon Macie membership invitations that were received by an account | Read |  |  |
GetMacieSession | Grants permission to retrieve information about the status and configuration settings for an Amazon Macie account | Read |  |  |
GetMasterAccount | Grants permission to retrieve information about the Amazon Macie administrator account for an account | Read |  |  |
GetMember | Grants permission to retrieve information about an account that's associated with an Amazon Macie administrator account | Read | Member* |  |
GetResourceProfile | Grants permission to retrieve sensitive data discovery statistics and the sensitivity score for an S3 bucket | Read |  |  |
GetRevealConfiguration | Grants permission to retrieve the status and configuration settings for retrieving occurrences of sensitive data reported by findings | Read |  |  |
GetSensitiveDataOccurrences | Grants permission to retrieve occurrences of sensitive data reported by a finding | Read |  |  |
GetSensitiveDataOccurrencesAvailability | Grants permission to check whether occurrences of sensitive data can be retrieved for a finding | Read |  |  |
GetSensitivityInspectionTemplate | Grants permission to retrieve the sensitivity inspection template settings for an account | Read |  |  |
GetUsageStatistics | Grants permission to retrieve quotas and aggregated usage data for one or more accounts | Read |  |  |
GetUsageTotals | Grants permission to retrieve aggregated usage data for an account | Read |  |  |
ListAllowLists | Grants permission to retrieve a subset of information about all the allow lists for an account | List |  |  |
ListClassificationJobs | Grants permission to retrieve a subset of information about the status and settings for one or more sensitive data discovery jobs | List |  |  |
ListClassificationScopes | Grants permission to retrieve a subset of information about the classification scope for an account | List |  |  |
ListCustomDataIdentifiers | Grants permission to retrieve information about all custom data identifiers | List |  |  |
ListFindings | Grants permission to retrieve a subset of information about one or more findings | List |  |  |
ListFindingsFilters | Grants permission to retrieve information about all findings filters | List |  |  |
ListInvitations | Grants permission to retrieve information about all the Amazon Macie membership invitations that were received by an account | List |  |  |
ListManagedDataIdentifiers | Grants permission to retrieve information about managed data identifiers | List |  |  |
ListMembers | Grants permission to retrieve information about the Amazon Macie member accounts that are associated with a Macie administrator account | List |  |  |
ListOrganizationAdminAccounts | Grants permission to retrieve information about the delegated, Amazon Macie administrator account for an AWS organization | List |  |  |
ListResourceProfileArtifacts | Grants permission to retrieve information about objects that were selected from an S3 bucket for automated sensitive data discovery | List |  |  |
ListResourceProfileDetections | Grants permission to retrieve information about the types and amount of sensitive data that Amazon Macie found in an S3 bucket | List |  |  |
ListSensitivityInspectionTemplates | Grants permission to retrieve a subset of information about the sensitivity inspection template for an account | List |  |  |
ListTagsForResource | Grants permission to retrieve the tags for an Amazon Macie resource | Read | AllowList |  |
ClassificationJob |  |
CustomDataIdentifier |  |
FindingsFilter |  |
Member |  |
PutClassificationExportConfiguration | Grants permission to create or update the settings for storing sensitive data discovery results | Write |  |  |
PutFindingsPublicationConfiguration | Grants permission to update the configuration settings for publishing findings to AWS Security Hub | Write |  |  |
SearchResources | Grants permission to retrieve statistical data and other information about AWS resources that Amazon Macie monitors and analyzes | Read |  |  |
TagResource | Grants permission to add or update the tags for an Amazon Macie resource | Tagging | AllowList |  |
ClassificationJob |  |
CustomDataIdentifier |  |
FindingsFilter |  |
Member |  |
| aws:RequestTag/${TagKey} aws:TagKeys |
TestCustomDataIdentifier | Grants permission to test a custom data identifier | Write |  |  |
UntagResource | Grants permission to remove tags from an Amazon Macie resource | Tagging | AllowList |  |
ClassificationJob |  |
CustomDataIdentifier |  |
FindingsFilter |  |
Member |  |
| aws:TagKeys |
UpdateAllowList | Grants permission to update the settings for an allow list | Write | AllowList* |  |
UpdateAutomatedDiscoveryConfiguration | Grants permission to enable or disable automated sensitive data discovery for an account | Write |  |  |
UpdateClassificationJob | Grants permission to change the status of a sensitive data discovery job | Write | ClassificationJob* |  |
| aws:RequestTag/${TagKey} aws:TagKeys |
UpdateClassificationScope | Grants permission to update the classification scope settings for an account | Write |  |  |
UpdateFindingsFilter | Grants permission to update the settings for a findings filter | Write | FindingsFilter* |  |
| aws:RequestTag/${TagKey} aws:TagKeys |
UpdateMacieSession | Grants permission to suspend or re-enable an Amazon Macie account, or update the configuration settings for a Macie account | Write |  |  |
UpdateMemberSession | Grants permission to an Amazon Macie administrator account to suspend or re-enable a Macie member account | Write |  |  |
UpdateOrganizationConfiguration | Grants permission to update Amazon Macie configuration settings for an AWS organization | Write |  |  |
UpdateResourceProfile | Grants permission to update the sensitivity score for an S3 bucket | Write |  |  |
UpdateResourceProfileDetections | Grants permission to update the sensitivity scoring settings for an S3 bucket | Write |  |  |
UpdateRevealConfiguration | Grants permission to update the status and configuration settings for retrieving occurrences of sensitive data reported by findings | Write |  |  |
UpdateSensitivityInspectionTemplate | Grants permission to update the sensitivity inspection template settings for an account | Write |  |  |

## Resource types defined by Amazon Macie

The following resource types are defined by this service and can be used in the `Resource` element of IAM permission policy statements. Each action in the Actions table identifies the resource types that can be specified with that action. A resource type can also define which condition keys you can include in a policy. These keys are displayed in the last column of the Resource types table. For details about the columns in the following table, see Resource types table .

Resource types | ARN | Condition keys
--- | --- | ---
AllowList | `arn:$ { Partition}:macie2:$ { Region}:$ { Account}:allow-list/$ { ResourceId}` | aws:ResourceTag/${TagKey}
ClassificationJob | `arn:$ { Partition}:macie2:$ { Region}:$ { Account}:classification-job/$ { ResourceId}` | aws:ResourceTag/${TagKey}
CustomDataIdentifier | `arn:$ { Partition}:macie2:$ { Region}:$ { Account}:custom-data-identifier/$ { ResourceId}` | aws:ResourceTag/${TagKey}
FindingsFilter | `arn:$ { Partition}:macie2:$ { Region}:$ { Account}:findings-filter/$ { ResourceId}` | aws:ResourceTag/${TagKey}
Member | `arn:$ { Partition}:macie2:$ { Region}:$ { Account}:member/$ { ResourceId}` | aws:ResourceTag/${TagKey}

## Condition keys for Amazon Macie

Amazon Macie defines the following condition keys that can be used in the `Condition` element of an IAM policy. You can use these keys to further refine the conditions under which the policy statement applies. For details about the columns in the following table, see Condition keys table .

To view the global condition keys that are available to all services, see Available global condition keys .

Condition keys | Description | Type
--- | --- | ---
aws:RequestTag/${TagKey} | Filters access by a tag key and value pair that is allowed in the request | String
aws:ResourceTag/${TagKey} | Filters access by a tag key and value pair of a resource | String
aws:TagKeys | Filters access by the presence of tag keys in the request | ArrayOfString

Did this page help you? - Yes

Thanks for letting us know we're doing a good job!

If you've got a moment, please tell us what we did right so we can do more of it.

Did this page help you? - No

Thanks for letting us know this page needs work. We're sorry we let you down.

If you've got a moment, please tell us how we can make the documentation better.